@@ -193,7 +193,7 @@ bool KBuildSycoca::build()
         const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, m_resourceSubdir, QStandardPaths::LocateDirectory);
         qCDebug(SYCOCA) << "Looking for subdir" << m_resourceSubdir << "=>" << dirs;
         for (const QString &dir : dirs) {
-            QDirIterator it(dir, QDirIterator::Subdirectories);
+            QDirIterator it(dir, QDirIterator::Subdirectories | QDirIterator::FollowSymlinks);
             while (it.hasNext()) {
                 const QString filePath = it.next();
                 Q_ASSERT(filePath.startsWith(dir)); // due to the line below...
@@ -420,7 +420,12 @@ bool KBuildSycoca::recreate(bool incremental)
             const int uid = qEnvironmentVariableIntValue("SUDO_UID");
             const int gid = qEnvironmentVariableIntValue("SUDO_GID");
             if (uid && gid) {
-                fchown(database.handle(), uid, gid);
+                int ret;
+                ret = fchown(database.handle(), uid, gid);
+                if (ret < 0) {
+                    qCWarning(SYCOCA) << "ERROR changing ownership of database" << database.fileName() << strerror(errno);
+                    return false;
+                }
             }
         }
 #endif
